@@ -8,10 +8,11 @@ pub fn comment(options: &Options) -> String {
     format!(
         "
 // Comment
-{comment_blob} {ns}__new({loc_blob} location, {comment_type_blob} kind);
-{loc_blob} *{ns}__get_location({comment_blob} *blob);
-{comment_type_blob} *{ns}__get_kind({comment_blob} *blob);
-void {ns}__drop({comment_blob} *blob);",
+{comment_blob} {ns}__new({loc_blob} location_blob, {comment_type_blob} kind_blob);
+void {ns}__drop({comment_blob} *self_blob);
+const {loc_blob} *{ns}__get_location(const {comment_blob} *self_blob);
+const {comment_type_blob} *{ns}__get_kind(const {comment_blob} *self_blob);
+",
         ns = ns(),
         comment_blob = options.comment_blob_name,
         loc_blob = options.loc_blob_name,
