@@ -10,9 +10,11 @@ pub fn comment_type(options: &Options) -> String {
 {comment_type_blob} {ns}__new_inline();
 {comment_type_blob} {ns}__new_document();
 {comment_type_blob} {ns}__new_unknown();
-bool {ns}__is_inline({comment_type_blob} blob);
-bool {ns}__is_document({comment_type_blob} blob);
-bool {ns}__is_unknown({comment_type_blob} blob);",
+void {ns}__drop({comment_type_blob} *self_blob);
+bool {ns}__is_inline(const {comment_type_blob} *self_blob);
+bool {ns}__is_document(const {comment_type_blob} *self_blob);
+bool {ns}__is_unknown(const {comment_type_blob} *self_blob);
+",
         ns = ns(),
         comment_type_blob = options.comment_type_blob_name
     )
