@@ -10,8 +10,10 @@ pub fn error_level(options: &Options) -> String {
 // ErrorLevel
 {error_level_blob} {ns}__new_warning();
 {error_level_blob} {ns}__new_error();
-bool {ns}__is_warning({error_level_blob} blob);
-bool {ns}__is_error({error_level_blob} blob);",
+void {ns}__drop({error_level_blob} *self_blob);
+bool {ns}__is_warning(const {error_level_blob} *self_blob);
+bool {ns}__is_error(const {error_level_blob} *self_blob);
+",
         ns = ns(),
         error_level_blob = options.error_level_blob_name,
     )
