@@ -48,17 +48,18 @@ fn ns(subns: &str) -> String {
 fn list_of(item_blob: &str, list_blob: &str, subns: &str) -> String {
     format!(
         "
-// Vec<{item_blob}>
+// List<{item_blob}>
 {list_blob} {ns}__new();
-void {ns}__drop({list_blob} *blob);
+void {ns}__drop({list_blob} *self_blob);
 {list_blob} {ns}__with_capacity(uint64_t capacity);
 {list_blob} {ns}__from_raw({item_blob} *ptr, uint64_t len);
-void {ns}__push({list_blob} *blob, {item_blob} item_blob);
-{item_blob} {ns}__remove({list_blob} *blob, uint64_t index);
-void {ns}__shrink_to_fit({list_blob} *blob);
-{item_blob} *{ns}__as_ptr({list_blob} *blob);
-uint64_t {ns}__len(const {list_blob} *blob);
-uint64_t {ns}__capacity(const {list_blob} *blob);",
+void {ns}__push({list_blob} *self_blob, {item_blob} item_blob);
+{item_blob} {ns}__remove({list_blob} *self_blob, uint64_t index);
+void {ns}__shrink_to_fit({list_blob} *self_blob);
+{item_blob} *{ns}__as_ptr({list_blob} *self_blob);
+uint64_t {ns}__get_len(const {list_blob} *self_blob);
+uint64_t {ns}__get_capacity(const {list_blob} *self_blob);
+",
         ns = ns(subns),
         list_blob = list_blob,
         item_blob = item_blob
