@@ -9,9 +9,10 @@ pub fn loc(options: &Options) -> String {
         "
 // Loc
 {loc_blob} {ns}__new(uint64_t begin, uint64_t end);
-uint64_t {ns}__begin(const {loc_blob} *blob);
-uint64_t {ns}__end(const {loc_blob} *blob);
-void {ns}__drop({loc_blob} *blob);",
+void {ns}__drop({loc_blob} *self_blob);
+uint64_t {ns}__get_begin(const {loc_blob} *self_blob);
+uint64_t {ns}__get_end(const {loc_blob} *self_blob);
+",
         ns = ns(),
         loc_blob = options.loc_blob_name
     )
