@@ -12,11 +12,12 @@ pub fn magic_comment_kind(options: &Options) -> String {
 {magic_comment_kind_blob} {ns}__new_frozen_string_literal();
 {magic_comment_kind_blob} {ns}__new_warn_indent();
 {magic_comment_kind_blob} {ns}__new_shareable_constant_value();
-
-bool {ns}__is_encoding({magic_comment_kind_blob} blob);
-bool {ns}__is_frozen_string_literal({magic_comment_kind_blob} blob);
-bool {ns}__is_warn_indent({magic_comment_kind_blob} blob);
-bool {ns}__is_shareable_constant_value({magic_comment_kind_blob} blob);",
+void {ns}__drop({magic_comment_kind_blob}* self_blob);
+bool {ns}__is_encoding(const {magic_comment_kind_blob} *self_blob);
+bool {ns}__is_frozen_string_literal(const {magic_comment_kind_blob} *self_blob);
+bool {ns}__is_warn_indent(const {magic_comment_kind_blob} *self_blob);
+bool {ns}__is_shareable_constant_value(const {magic_comment_kind_blob} *self_blob);
+",
         ns = ns(),
         magic_comment_kind_blob = options.magic_comment_kind_blob_name
     )
