@@ -8,11 +8,12 @@ pub fn maybe_ptr(options: &Options) -> String {
     format!(
         "
 // MaybePtr
-{maybe_ptr_blob} {ns}__new(void *ptr);
+{maybe_ptr_blob} {ns}__new(void *raw);
 {maybe_ptr_blob} {ns}__new_null();
-void *{ns}__get_raw({maybe_ptr_blob} *blob);
-void {ns}__of_node__free({maybe_ptr_blob} *blob);
-void {ns}__of_token__free({maybe_ptr_blob} *blob);",
+void {ns}__of_node__drop({maybe_ptr_blob} *self_blob);
+void {ns}__of_token__drop({maybe_ptr_blob} *self_blob);
+void *{ns}__get_raw({maybe_ptr_blob} *self_blob);
+",
         ns = ns(),
         maybe_ptr_blob = options.maybe_ptr_blob_name,
     )
