@@ -9,10 +9,10 @@ pub fn ptr(options: &Options) -> String {
         "
 // Ptr
 {ptr_blob} {ns}__new(void *ptr);
-{ptr_blob} {ns}__new_null();
-void *{ns}__get_raw({ptr_blob} *blob);
-void {ns}__of_node__free({ptr_blob} *blob);
-void {ns}__of_token__free({ptr_blob} *blob);",
+void {ns}__of_node__drop({ptr_blob} *self_blob);
+void {ns}__of_token__drop({ptr_blob} *self_blob);
+void *{ns}__get_raw({ptr_blob} *self_blob);
+",
         ns = ns(),
         ptr_blob = options.ptr_blob_name
     )
