@@ -9,8 +9,10 @@ pub fn shared_byte_list(options: &Options) -> String {
         "
 // SharedByteList
 {shared_byte_list_blob} {ns}__new(const uint8_t *ptr, uint64_t len);
-const uint8_t *{ns}__get_raw(const {shared_byte_list_blob} *blob);
-uint64_t {ns}__get_len(const {shared_byte_list_blob} *blob);",
+void {ns}__drop({shared_byte_list_blob} *self_blob);
+const uint8_t *{ns}__get_raw(const {shared_byte_list_blob} *self_blob);
+uint64_t {ns}__get_len(const {shared_byte_list_blob} *self_blob);
+",
         ns = ns(),
         shared_byte_list_blob = options.shared_byte_list_blob_name
     )
