@@ -16,7 +16,7 @@ fn arglist(message: &Message, options: &Options) -> String {
         .fields
         .map(&|field| {
             format!(
-                "{field_type} {field_name}",
+                "{field_type} {field_name}_blob",
                 field_type = fields::field_type(field, options),
                 field_name = fields::field_name(field)
             )
