@@ -15,7 +15,7 @@ pub fn name(message: &Message, field: &MessageField) -> String {
 /// Returns C signature of the field getter for the given `message`/`field` pair
 pub fn sig(message: &Message, field: &MessageField, options: &Options) -> String {
     format!(
-        "const {return_type} *{getter_name}(const {message_variant_blob} *blob)",
+        "const {return_type} *{getter_name}(const {message_variant_blob} *self_blob)",
         return_type = fields::field_type(field, options),
         getter_name = name(message, field),
         message_variant_blob = options.message_variant_blob_name(message),
