@@ -14,7 +14,7 @@ pub fn name(message: &Message) -> String {
 /// Returns C signature of the cast-to-variant function for the given `message`
 pub fn sig(message: &Message, options: &Options) -> String {
     format!(
-        "const {message_variant_blob} *{variant_getter_name}(const {diagnostic_message_blob} *blob)",
+        "const {message_variant_blob} *{variant_getter_name}(const {diagnostic_message_blob} *self_blob)",
         variant_getter_name = name(message),
         message_variant_blob = options.message_variant_blob_name(message),
         diagnostic_message_blob = options.diagnostic_message_blob_name
