@@ -4,14 +4,14 @@ use lib_ruby_parser_nodes::Node;
 
 /// Returns name of the constructor for the given `node`
 pub fn name(node: &Node) -> String {
-    format!("{ns}__make_{lower}", ns = ns(), lower = node.lower_name())
+    format!("{ns}__new_{lower}", ns = ns(), lower = node.lower_name())
 }
 
 fn arglist(node: &Node, options: &Options) -> String {
     node.fields
         .map(&|field| {
             format!(
-                "{field_type} {name}",
+                "{field_type} {name}_blob",
                 field_type = fields::field_type(field, options),
                 name = fields::field_name(field)
             )
