@@ -10,7 +10,7 @@ pub fn name(node: &Node) -> String {
 /// Returns name of the destructor for the given `node`
 pub fn sig(node: &Node, options: &Options) -> String {
     format!(
-        "void {fn_name}({node_variant_blob} *blob)",
+        "void {fn_name}({node_variant_blob} *self_blob)",
         fn_name = name(node),
         node_variant_blob = options.node_variant_blob_name(node),
     )
