@@ -15,7 +15,7 @@ pub fn name(node: &Node, field: &NodeField) -> String {
 /// Returns C signature of the node field getter for the given `node`/`field` pair
 pub fn sig(node: &Node, field: &NodeField, options: &Options) -> String {
     format!(
-        "{return_type} *{getter_name}({node_variant_blob} *blob)",
+        "{return_type} *{getter_name}({node_variant_blob} *self_blob)",
         return_type = fields::field_type(field, options),
         getter_name = name(node, field),
         node_variant_blob = options.node_variant_blob_name(node)
