@@ -10,7 +10,7 @@ pub fn name(node: &Node) -> String {
 /// Returns C signature of the cast-to-variant fn for the given `node`
 pub fn sig(node: &Node, options: &Options) -> String {
     format!(
-        "{node_variant_blob} {fn_name}({node_blob} blob)",
+        "{node_variant_blob} {fn_name}({node_blob} self_blob)",
         node_variant_blob = options.node_variant_blob_name(node),
         fn_name = name(node),
         node_blob = options.node_blob_name
