@@ -10,7 +10,7 @@ pub fn name(node: &Node) -> String {
 /// Returns name of the is-a-variant function for the given `node`
 pub fn sig(node: &Node, options: &Options) -> String {
     format!(
-        "bool {variant_predicate_name}(const {node_blob}* blob)",
+        "bool {variant_predicate_name}(const {node_blob}* self_blob)",
         variant_predicate_name = name(node),
         node_blob = options.node_blob_name
     )
